.. Copyright (c) Moshe Zadka
   See LICENSE for details.

CapArg
------

Captain Arguments -- make it easy to run subcommands.

.. image:: https://travis-ci.org/moshez/caparg.svg?branch=master
    :target: https://travis-ci.org/moshez/caparg

.. image:: https://readthedocs.org/projects/caparg/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://readthedocs.org/projects/caparg/

Hacking
=======

  $ tox

Should DTRT -- if it passes, it means
unit tests are passing, and 100% coverage.

Contributors
=============

Moshe Zadka <zadka.moshe@gmail.com>

License
=======

MIT License
